Add scheduled segment contents to the queue... in theory at least... :)
authorChristopher Allan Webber <cwebber@dustycloud.org>
Thu, 19 Nov 2015 21:33:37 +0000 (15:33 -0600)
committerChristopher Allan Webber <cwebber@dustycloud.org>
Thu, 19 Nov 2015 21:33:37 +0000 (15:33 -0600)
loopy.scm

index 2f733c01d4fe32afa21641bc456c37efc4f0f171..e96b130e75bb667647be65b6162559caa0124c6e 100644 (file)
--- a/loopy.scm
+++ b/loopy.scm
 
 (define* (start-agenda agenda #:optional stop-condition)
   (let loop ((agenda agenda))
-    (let ((new-agenda   
+    (let ((agenda   
            ;; @@: Hm, maybe here would be a great place to handle
            ;;   select'ing on ports.
            ;;   We could compose over agenda-run-once and agenda-read-ports
              (agenda-run-once agenda))))
       (if (and stop-condition (stop-condition agenda))
           'done
-          (let ((updated-agenda
-                 ;; Adjust the agenda's time just in time
-                 ;; We do this here rather than in agenda-run-once to make
-                 ;; agenda-run-once's behavior fairly predictable
-                 (set-field new-agenda (agenda-time) (gettimeofday))))
-            (loop updated-agenda))))))
+          (let* ((new-time (gettimeofday))
+                 (agenda
+                  ;; Adjust the agenda's time just in time
+                  ;; We do this here rather than in agenda-run-once to make
+                  ;; agenda-run-once's behavior fairly predictable
+                  (set-field agenda (agenda-time) new-time)))
+            ;; Update the agenda's current queue based on
+            ;; currently applicable time segments
+            (add-segments-contents-to-queue!
+             (schedule-extract-until! (agenda-schedule agenda) new-time)
+             (agenda-queue agenda))
+            (loop agenda))))))
 
 (define (agenda-run-once agenda)
   "Run once through the agenda, and produce a new agenda